.. demoparser documentation master file, created by
   sphinx-quickstart on Thu Oct  5 16:48:03 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to demoparser's documentation!
======================================

.. include:: ../../README.rst

Contents:

.. toctree::
   :maxdepth: 1

   usage
   events
   API Documentation <api/modules>

